@@ -7,24 +7,26 @@
 #' @param y Second categorical variable - values will appear in as column names.
 #' @param prop Proportions to display;  \dQuote{r} for \emph{rows} (default),
 #'   \dQuote{c} for \emph{columns}, \dQuote{t} for \emph{total}, or \dQuote{n} for
-#'   \emph{none}.
+#'   \emph{none}. This option can be set globally; see \code{\link{st_options}}.
 #' @param useNA Argument passed on to \code{\link[base]{table}}; One of \dQuote{ifany}
 #'   (default), \dQuote{no}, or \dQuote{always}.
 #' @param totals Logical. Should row and column totals be displayed? Defaults to \code{TRUE}.
+#'    To change this default value globally, see \code{\link{st_options}}.
 #' @param style Style to be used by \code{\link[pander]{pander}} when rendering
 #'   output table; One of \dQuote{simple} (default), \dQuote{grid}, or \dQuote{rmarkdown} 
-#'   (see details section about the latter).
+#'   This option can be set globally; see \code{\link{st_options}}.
 #' @param round.digits Number of significant digits to display. Defaults to
-#'   \code{1}.
-#'   \dQuote{rmarkdown}.
+#'   \code{1}. To change this default value globally, see \code{\link{st_options}}.
 #' @param justify String indicating alignment of columns; one of \dQuote{l} (left)
 #'   \dQuote{c} (center), or \dQuote{r} (right). Defaults to \dQuote{r}.
-#' @param omit.headings Logical. Set to \code{TRUE} to omit headings.
+#' @param omit.headings Logical. Set to \code{TRUE} to omit heading section. Can be set
+#'   globally via \code{\link{st_options}}.
 #' @param plain.ascii Logical. \code{\link[pander]{pander}} argument; when
 #'   \code{TRUE}, no markup characters will be used (useful when printing
-#'   to console). Defaults to \code{TRUE} when \code{style} is \dQuote{simple},
-#'   and \code{FALSE} otherwise.
-#' @param split.table Pander argument that specifies how many characters wide a
+#'   to console). Defaults to \code{TRUE} unless \code{style = 'rmarkdown'},
+#'   in which case it will be set to \code{FALSE} automatically. To change the default 
+#'   value globally, see \code{\link{st_options}}.
+#' @param split.tables Pander argument that specifies how many characters wide a
 #'   table can be. \code{Inf} by default.
 #' @param dnn Names to be used in output table. Vector of two strings; By default,
 #'   the character values for arguments x and y are used.
@@ -47,12 +49,16 @@
 #' @keywords classes category
 #' @author Dominic Comtois, \email{dominic.comtois@@gmail.com}
 #' @export
-ctable <- function(x, y, prop = "r", useNA = "ifany", totals = TRUE, style = "simple", 
-                   round.digits = 1, justify = "right",  omit.headings = FALSE, 
-                   plain.ascii = TRUE, split.table = Inf, dnn=c(substitute(x), substitute(y)),
+ctable <- function(x, y, prop = st_options('ctable.prop'), useNA = 'ifany', 
+                   totals = st_options('ctable.totals'), style = st_options('style'), 
+                   round.digits = 1, justify = 'right', 
+                   omit.headings = st_options('omit.headings'), 
+                   plain.ascii = st_options('plain.ascii'), split.tables = Inf, 
+                   dnn=c(substitute(x), substitute(y)),
                    ...) {
 
-  # Parameter validation ---------------------------------------
+  # Parameter validation ------------------------------------------------------
+  
   if (!is.factor(x) && !is.atomic(x)) {
     x <- try(as.vector(x), silent = TRUE)
     if (class(x) == "try-except") {
@@ -115,7 +121,7 @@ ctable <- function(x, y, prop = "r", useNA = "ifany", totals = TRUE, style = "si
     plain.ascii <- FALSE
   }
 
-  # Replace NaN's by NA's (This simplifies matters a lot!)
+  # Replace NaN's by NA's (This simplifies matters a lot)
   if (NaN %in% x)  {
     message(paste(sum(is.nan(x)), "NaN value(s) converted to NA in x\n"))
     x[is.nan(x)] <- NA
@@ -171,7 +177,7 @@ ctable <- function(x, y, prop = "r", useNA = "ifany", totals = TRUE, style = "si
     y_subset <- NA
   }
 
-  # Create cross-freq table
+  # Create cross-freq table ---------------------------------------------------
   freq_table <- table(x, y, useNA = useNA)
 
   names(dimnames(freq_table)) <- c(x_name, y_name)
@@ -182,30 +188,28 @@ ctable <- function(x, y, prop = "r", useNA = "ifany", totals = TRUE, style = "si
                        Column = prop.table(freq_table, 2),
                        None = NULL)
 
-  # When useNA = "always" and there are no NA's, we had nan's (0 div by 0)
+  # When useNA = "always" and there are no NA's, we have NAN's (0 div by 0)
   prop_table[is.nan(prop_table)] <- 0
 
-  if (isTRUE(totals)) {
-    freq_table <- addmargins(freq_table)
-    rownames(freq_table)[nrow(freq_table)] <- "Total"
-    colnames(freq_table)[ncol(freq_table)] <- "Total"
-    #if (!is.null(prop_table)) {
-    if (length(prop_table) > 0) {
-      if (prop == "Total") {
-        prop_table <- addmargins(prop_table)
-      } else if (prop == "Row") {
-        prop_table <- addmargins(prop_table, 2)
-        sum_props <- c(prop.table(freq_table[nrow(freq_table), -ncol(freq_table)]), Total=1)
-        prop_table <- rbind(prop_table, sum_props)
-      } else if (prop == "Column") {
-        prop_table <- addmargins(prop_table, 1)
-        sum_props <- c(prop.table(freq_table[-nrow(freq_table), ncol(freq_table)]), Total=1)
-        prop_table <- cbind(prop_table, sum_props)
-      }
-
-      rownames(prop_table)[nrow(prop_table)] <- "Total"
-      colnames(prop_table)[ncol(prop_table)] <- "Total"
+  # Add totals
+  freq_table <- addmargins(freq_table)
+  rownames(freq_table)[nrow(freq_table)] <- "Total"
+  colnames(freq_table)[ncol(freq_table)] <- "Total"
+  if (length(prop_table) > 0) {
+    if (prop == "Total") {
+      prop_table <- addmargins(prop_table)
+    } else if (prop == "Row") {
+      prop_table <- addmargins(prop_table, 2)
+      sum_props <- c(prop.table(freq_table[nrow(freq_table), -ncol(freq_table)]), Total=1)
+      prop_table <- rbind(prop_table, sum_props)
+    } else if (prop == "Column") {
+      prop_table <- addmargins(prop_table, 1)
+      sum_props <- c(prop.table(freq_table[-nrow(freq_table), ncol(freq_table)]), Total=1)
+      prop_table <- cbind(prop_table, sum_props)
     }
+
+    rownames(prop_table)[nrow(prop_table)] <- "Total"
+    colnames(prop_table)[ncol(prop_table)] <- "Total"
   }
 
   # Change the name of NA items to avoid potential problems when echoing to console
@@ -223,39 +227,41 @@ ctable <- function(x, y, prop = "r", useNA = "ifany", totals = TRUE, style = "si
     }
   }
 
-  # Create output object
+  # Create output object ------------------------------------------------------
+  
   output <- list(cross_table = freq_table, proportions = prop_table)
 
   # Set output object's attributes
   class(output) <- c("summarytools", class(output))
   attr(output, "st_type") <- "ctable"
+  attr(output, "fn_call") <- match.call()
   attr(output, "proportions") <- prop
-  attr(output, "fn_call") <- as.character(match.call())
   attr(output, "date") <- Sys.Date()
 
   data_info <-
-    list(Dataframe = ifelse(exists("df_name"), df_name, NA),
-         Dataframe.label = ifelse(exists("df_label"), df_label, NA),
-         Row.variable = x_name,
+    list(Dataframe          = ifelse(exists("df_name"), df_name, NA),
+         Dataframe.label    = ifelse(exists("df_label"), df_label, NA),
+         Row.variable       = x_name,
          Row.variable.label = ifelse(!is.na(label(x)), label(x), NA),
-         Col.variable = y_name,
+         Col.variable       = y_name,
          Col.variable.label = ifelse(!is.na(label(y)), label(y), NA),
-         Subset = ifelse(length(x_subset) == 1 &&
-                           length(y_subset) == 1 &&
-                           x_subset == y_subset, x_subset, NA),
+         Row.x.Col          = paste(x_name, y_name, sep = " * "),
+         Subset             = ifelse(length(x_subset) == 1 &&
+                                     length(y_subset) == 1 &&
+                                     x_subset == y_subset, x_subset, NA),
          Row.variable.subset = ifelse((x_subset != y_subset) && length(x_subset) == 1, x_subset, NA),
          Col.variable.subset = ifelse((x_subset != y_subset) && length(y_subset) == 1, y_subset, NA))
 
   attr(output, "data_info") <-  data_info[!is.na(data_info)]
 
-  attr(output, "formatting") <-
-    list(style         = style,
-         round.digits  = round.digits,
-         plain.ascii   = plain.ascii,
-         justify       = justify,
-         split.table   = split.table,
-         omit.headings = omit.headings)
-
+  attr(output, "formatting") <-  list(style         = style,
+                                      round.digits  = round.digits,
+                                      plain.ascii   = plain.ascii,
+                                      justify       = justify,
+                                      totals        = totals,
+                                      split.tables  = split.tables,
+                                      omit.headings = omit.headings)
+  
   attr(output, "user_fmt") <- list(... = ...)
 
   return(output)
